Re-exports
pub use serde_json;pub use wasm_bindgen;pub use paste;pub use serde;pub use crate::traits::*;
Macros
Structs
- The
NamedNodeMapclass. - The
ShadowRootclass.
Traits
- A data structure that can be deserialized from any data format supported by Serde.
- A data structure that can be serialized into any data format supported by Serde.