LaunchConfig

Trait LaunchConfig 

pub trait LaunchConfig: 'static { }
A marker trait for platform configs. We use this marker to make sure that the user doesn’t accidentally pass in a config builder instead of the config

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl LaunchConfig for ()

Source

impl LaunchConfig for Config

Implementors