ScaleOffset2D

Struct ScaleOffset2D 

pub struct ScaleOffset2D<T, Src, Dst> {
    pub sx: T,
    pub sy: T,
    pub tx: T,
    pub ty: T,
    /* private fields */
}

Fields

sx: Tsy: Ttx: Tty: T

Implementations

Source

impl<T, Src, Dst> ScaleOffset2D<T, Src, Dst>

pub fn identity() -> ScaleOffset2D<T, Src, Dst>
where T: Zero + One,

Create an identity transform.

pub fn new(sx: T, sy: T, tx: T, ty: T) -> ScaleOffset2D<T, Src, Dst>

Create a transform with provided scale and offset terms.

pub fn scale(sx: T, sy: T) -> ScaleOffset2D<T, Src, Dst>
where T: Zero,

Create a transform from a scale.

pub fn offset(tx: T, ty: T) -> ScaleOffset2D<T, Src, Dst>
where T: One,

Create a transform from an offset.

Source

impl<T, Src, Dst> ScaleOffset2D<T, Src, Dst>
where T: Copy,

pub fn transform_point(&self, p: Point2D<T, Src>) -> Point2D<T, Dst>
where T: Add<Output = T> + Mul<Output = T>,

Returns the given point transformed by this transform.

pub fn transform_vector(&self, v: Vector2D<T, Src>) -> Vector2D<T, Dst>
where T: Mul<Output = T>,

Returns the given vector transformed by this transform.

pub fn transform_box(&self, b: &Box2D<T, Src>) -> Box2D<T, Dst>
where T: Zero + Add<Output = T> + Mul<Output = T> + PartialOrd,

Returns the given box transformed by this transform.

pub fn transform_rect(&self, r: &Rect<T, Src>) -> Rect<T, Dst>
where T: Zero + Add<Output = T> + Sub<Output = T> + Mul<Output = T> + PartialOrd,

Returns the given rectangle transformed by this transform.

pub fn then<NewDst>( &self, other: &ScaleOffset2D<T, Dst, NewDst>, ) -> ScaleOffset2D<T, Src, NewDst>
where T: Add<Output = T> + Mul<Output = T>,

Produce a ScaleOffset2D that includes both self and other. The ‘other’ ScaleOffset2D is applied after self.

This is equivalent to Transform2D::then.

pub fn pre_translate(&self, v: Vector2D<T, Src>) -> ScaleOffset2D<T, Src, Dst>
where T: Add<Output = T> + Mul<Output = T>,

Applies a translation before self’s transformation and returns the resulting transform.

pub fn then_translate(&self, v: Vector2D<T, Dst>) -> ScaleOffset2D<T, Src, Dst>
where T: Add<Output = T> + Mul<Output = T>,

Applies a translation after self’s transformation and returns the resulting transform.

pub fn pre_scale(&self, sx: T, sy: T) -> ScaleOffset2D<T, Src, Dst>
where T: Add<Output = T> + Mul<Output = T>,

Applies a scale before self’s transformation and returns the resulting transform.

pub fn then_scale(&self, sx: T, sy: T) -> ScaleOffset2D<T, Src, Dst>
where T: Add<Output = T> + Mul<Output = T>,

Applies a scale after self’s transformation and returns the resulting transform.

pub fn is_invertible(&self) -> bool
where T: Zero + PartialEq,

Returns whether it is possible to compute the inverse transform.

pub fn inverse(&self) -> Option<ScaleOffset2D<T, Dst, Src>>
where T: Zero + One + PartialEq + Div<Output = T> + Mul<Output = T> + Neg<Output = T>,

Returns the inverse transform if possible.

pub fn to_transform2d(&self) -> Transform2D<T, Src, Dst>
where T: Zero,

Returns the same transform using Transform2D’s matrix representation.

pub fn to_transform3d(&self) -> Transform3D<T, Src, Dst>
where T: Zero + One,

Returns the same transform using Transform3D’s matrix representation.

pub fn to_array(&self) -> [T; 4]

Returns an array containing this transform’s terms.

The terms are laid out in the same order as they are specified in ScaleOffset2D::new.

pub fn with_source<NewSrc>(&self) -> ScaleOffset2D<T, NewSrc, Dst>

Returns the same transform with a different source unit.

pub fn with_destination<NewDst>(&self) -> ScaleOffset2D<T, Src, NewDst>

Returns the same transform with a different destination unit.

pub fn to_untyped(&self) -> ScaleOffset2D<T, UnknownUnit, UnknownUnit>

Drop the units, preserving only the numeric value.

pub fn from_untyped( val: ScaleOffset2D<T, UnknownUnit, UnknownUnit>, ) -> ScaleOffset2D<T, Src, Dst>

Tag a unitless value with units.

Source

impl<T, Src, Dst> ScaleOffset2D<T, Src, Dst>
where T: Copy,

pub fn is_identity(&self) -> bool
where T: One + Zero + ApproxEq<T>,

Returns true if self is an identity transform, using T’s default epsilon value.

pub fn is_identity_eps(&self, epsilon: T) -> bool
where T: One + Zero + ApproxEq<T>,

Returns true if self is an identity transform.