pub trait Dependency: Sized + Clone {
type Out: Clone + PartialEq + 'static;
// Required method
fn out(&self) -> Self::Out;
// Provided method
fn changed(&self, other: &Self::Out) -> bool { ... }
}Expand description
A dependency is a trait that can be used to determine if a effect or selector should be re-run.
Required Associated Types
Required Methods
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".