pub trait HasTouchData: ModifiersInteraction + Any {
// Required methods
fn touches(&self) -> Vec<TouchPoint>;
fn touches_changed(&self) -> Vec<TouchPoint>;
fn target_touches(&self) -> Vec<TouchPoint>;
fn as_any(&self) -> &(dyn Any + 'static);
}Required Methods
Sourcefn touches(&self) -> Vec<TouchPoint>
fn touches(&self) -> Vec<TouchPoint>
Get the touches that are currently down
Sourcefn touches_changed(&self) -> Vec<TouchPoint>
fn touches_changed(&self) -> Vec<TouchPoint>
Get the touches that have changed since the last event
Sourcefn target_touches(&self) -> Vec<TouchPoint>
fn target_touches(&self) -> Vec<TouchPoint>
Get the touches that started and stayed on the element that triggered this event
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".